@@ -12,9 +12,7 @@
  * General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
- * 02111-1307, USA.
+ * along with this program; if not, see <http://www.gnu.org/licenses/>.
  *
  * The Sushi project hereby grant permission for non-gpl compatible GStreamer
  * plugins to be used and distributed together with GStreamer and Sushi. This
@@ -25,6 +23,7 @@
  *
  */
 
+const Gio = imports.gi.Gio;
 const GLib = imports.gi.GLib;
 const GObject = imports.gi.GObject;
 const Gdk = imports.gi.Gdk;
@@ -85,7 +84,8 @@ MainWindow.prototype = {
                                            skipPagerHint: true,
                                            skipTaskbarHint: true,
                                            windowPosition: Gtk.WindowPosition.CENTER,
-                                           gravity: Gdk.Gravity.CENTER });
+                                           gravity: Gdk.Gravity.CENTER,
+                                           application: this._application });
 
         let screen = Gdk.Screen.get_default();
         this._gtkWindow.set_visual(screen.get_rgba_visual());
@@ -122,10 +122,10 @@ MainWindow.prototype = {
             new Clutter.BindConstraint({ coordinate: Clutter.BindCoordinate.SIZE,
                                          source: this._stage }));
         this._stage.add_actor(this._mainGroup);
-        this._mainGroup.set_opacity(0);
 
-        this._stage.connect('key-press-event',
-                            Lang.bind(this, this._onStageKeyPressEvent));
+        this._gtkWindow.connect('key-press-event',
+				Lang.bind(this, this._onKeyPressEvent));
+
         this._stage.connect('button-press-event',
                             Lang.bind(this, this._onButtonPressEvent));
         this._stage.connect('motion-event',
@@ -174,17 +174,19 @@ MainWindow.prototype = {
         this._clearAndQuit();
     },
 
-    _onStageKeyPressEvent : function(actor, event) {
-        let key = event.get_key_symbol();
+    _onKeyPressEvent : function(actor, event) {
+        let key = event.get_keyval()[1];
 
-        if (key == Clutter.KEY_Escape ||
-            key == Clutter.KEY_space ||
-            key == Clutter.KEY_q)
-            this._fadeOutWindow();
+        if (key == Gdk.KEY_Escape ||
+            key == Gdk.KEY_space ||
+            key == Gdk.KEY_q)
+            this._clearAndQuit();
 
-        if (key == Clutter.KEY_f ||
-            key == Clutter.KEY_F11)
+        if (key == Gdk.KEY_f ||
+            key == Gdk.KEY_F11)
             this.toggleFullScreen();
+
+        return false;
     },
 
     _onButtonPressEvent : function(actor, event) {
@@ -316,6 +318,7 @@ MainWindow.prototype = {
                             this._pendingRenderer.prepare(file, this, Lang.bind(this, this._onRendererPrepared));
                         } catch(e) {
                             /* FIXME: report the error */
+                            logError(e, 'Error calling prepare() on viewer');
                         }}));
     },
 
@@ -505,8 +508,8 @@ MainWindow.prototype = {
         this._toolbarActor.set_opacity(0);
 
         this._toolbarActor.margin_bottom = Constants.TOOLBAR_SPACING;
-        this._toolbarActor.margin_left = Constants.TOOLBAR_SPACING;
-        this._toolbarActor.margin_right = Constants.TOOLBAR_SPACING;
+        this._toolbarActor.margin_start = Constants.TOOLBAR_SPACING;
+        this._toolbarActor.margin_end = Constants.TOOLBAR_SPACING;
 
         this._mainLayout.add(this._toolbarActor,
                              Clutter.BinAlignment.CENTER, Clutter.BinAlignment.END);
@@ -560,8 +563,7 @@ MainWindow.prototype = {
         }
 
         this._titleGroupLayout = new Clutter.BoxLayout();
-        this._titleGroup =  new Clutter.Box({ layout_manager: this._titleGroupLayout,
-                                              opacity: 0 });
+        this._titleGroup =  new Clutter.Box({ layout_manager: this._titleGroupLayout });
         this._stage.add_actor(this._titleGroup);
 
         this._titleGroup.add_constraint(
@@ -610,47 +612,11 @@ MainWindow.prototype = {
     /**************************************************************************
      *********************** Window move/fade helpers *************************
      **************************************************************************/
-    _fadeInWindow : function() {
-        this._mainGroup.set_opacity(0);
-        this._titleGroup.set_opacity(0);
-
-        this._gtkWindow.show_all();
-
-        Tweener.addTween(this._mainGroup,
-                         { opacity: 255,
-                           time: 0.3,
-                           transition: 'easeOutQuad' });
-        Tweener.addTween(this._titleGroup,
-                         { opacity: 255,
-                           time: 0.3,
-                           transition: 'easeOutQuad' });
-    },
-
-    _fadeOutWindow : function() {
-        this._removeToolbarTimeout();
-
-        Tweener.addTween(this._titleGroup,
-                         { opacity: 0,
-                           time: 0.15,
-                           transition: 'easeOutQuad'
-                         });
-
-        Tweener.addTween(this._mainGroup,
-                         { opacity: 0,
-                           time: 0.15,
-                           transition: 'easeOutQuad',
-                           onComplete: function () {
-                               this._clearAndQuit();
-                           },
-                           onCompleteScope: this
-                         });
-    },
-
     _clearAndQuit : function() {
         if (this._renderer.clear)
             this._renderer.clear();
 
-        this._application.quit();
+        this._gtkWindow.destroy();
     },
 
     /**************************************************************************
@@ -659,7 +625,8 @@ MainWindow.prototype = {
     setParent : function(xid) {
         this._parent = Sushi.create_foreign_window(xid);
         this._gtkWindow.realize();
-        this._gtkWindow.get_window().set_transient_for(this._parent);
+        if (this._parent)
+            this._gtkWindow.get_window().set_transient_for(this._parent);
         this._gtkWindow.show_all();
 
         this._gtkWindow.get_window().move_to_current_desktop();
@@ -673,7 +640,7 @@ MainWindow.prototype = {
         this._createToolbar();
         this._createTitle();
 
-        this._fadeInWindow();
+        this._gtkWindow.show_all();
     },
 
     setTitle : function(label) {
@@ -699,6 +666,6 @@ MainWindow.prototype = {
     },
 
     close : function() {
-        this._fadeOutWindow();
+        this._clearAndQuit();
     }
 }
